@@ -3,6 +3,7 @@ import yaml
 from serverless.aws.functions.event_bridge import EventBridgeFunction
 from serverless.aws.functions.generic import Function
 from serverless.aws.functions.http import HTTPFunction
+from serverless.aws.functions.kinesis import KinesisFunction
 from serverless.aws.functions.s3 import S3Function
 from serverless.aws.iam import ServicePolicyBuilder
 from serverless.service.environment import Environment
@@ -39,7 +40,7 @@ class FunctionBuilder:
         return fn
 
     def http(
-            self, name, description, path, method, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, method, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(self.service, name, description, path, method, authorizer, handler, timeout, layers, **kwargs)
         self.service.functions.add(fn)
@@ -47,7 +48,7 @@ class FunctionBuilder:
         return fn
 
     def http_post(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.POST, authorizer, handler, timeout, layers, **kwargs
@@ -57,7 +58,7 @@ class FunctionBuilder:
         return fn
 
     def http_get(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.GET, authorizer, handler, timeout, layers, **kwargs
@@ -67,7 +68,7 @@ class FunctionBuilder:
         return fn
 
     def http_put(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.PUT, authorizer, handler, timeout, layers, **kwargs
@@ -77,7 +78,7 @@ class FunctionBuilder:
         return fn
 
     def http_patch(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.PATCH, authorizer, handler, timeout, layers, **kwargs
@@ -87,7 +88,7 @@ class FunctionBuilder:
         return fn
 
     def http_delete(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.DELETE, authorizer, handler, timeout, layers, **kwargs
@@ -97,7 +98,7 @@ class FunctionBuilder:
         return fn
 
     def http_options(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.OPTIONS, authorizer, handler, timeout, layers, **kwargs
@@ -107,7 +108,7 @@ class FunctionBuilder:
         return fn
 
     def http_any(
-            self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
+        self, name, description, path, authorizer=None, handler=None, timeout=None, layers=None, **kwargs
     ) -> HTTPFunction:
         fn = HTTPFunction(
             self.service, name, description, path, HTTPFunction.ANY, authorizer, handler, timeout, layers, **kwargs
@@ -117,17 +118,17 @@ class FunctionBuilder:
         return fn
 
     def event_bridge(
-            self,
-            name,
-            description,
-            eventBus,
-            pattern=None,
-            deadLetterQueueArn=None,
-            retryPolicy=None,
-            handler=None,
-            timeout=None,
-            layers=None,
-            **kwargs,
+        self,
+        name,
+        description,
+        eventBus,
+        pattern=None,
+        deadLetterQueueArn=None,
+        retryPolicy=None,
+        handler=None,
+        timeout=None,
+        layers=None,
+        **kwargs,
     ) -> EventBridgeFunction:
         fn = EventBridgeFunction(
             self.service,
@@ -152,13 +153,18 @@ class FunctionBuilder:
 
         return fn
 
+    def kinesis(self, stream, name, description, **kwargs):
+        fn = KinesisFunction(stream, self.service, name, description, **kwargs)
+        self.service.functions.add(fn)
+
+        return fn
+
 
 class Provider(BaseProvider, yaml.YAMLObject):
     yaml_tag = "!Provider"
 
     def __init__(
-            self, runtime=Runtime.PYTHON_3_8, extra_tags=None, timeout=10, stage="${sls:stage}", environment=None,
-            **kwargs
+        self, runtime=Runtime.PYTHON_3_8, extra_tags=None, timeout=10, stage="${sls:stage}", environment=None, **kwargs
     ):
         super().__init__(**kwargs)
         self.deploymentBucket = None
@@ -171,6 +177,7 @@ class Provider(BaseProvider, yaml.YAMLObject):
         self.timeout = timeout
         self.stage = stage
         self.tags = extra_tags or {}
+        self.stackTags = {}
         self.lambdaHashingVersion = 20201221
         self.environment = environment or Environment()
         self.iam = None
@@ -179,10 +186,15 @@ class Provider(BaseProvider, yaml.YAMLObject):
 
     def configure(self, service):
         self._service = service
+
         if service.config.domain:
             self.deploymentBucket = dict(name=f"sls-deployments.${{aws:region}}.${{sls:stage}}.{service.config.domain}")
+
         self.tags["SERVICE"] = "${self:service}"
-        self.iam = ServicePolicyBuilder()
+        self.tags["REGION"] = "${aws:region}"
+        self.tags["STAGE"] = "${sls:stage}"
+        self.stackTags = self.tags.copy()
+        self.iam = ServicePolicyBuilder(self._service)
         self.function_builder = FunctionBuilder(self._service)
 
     @classmethod
