@@ -3,6 +3,7 @@ from troposphere.dynamodb import Table as DynamoDBTable, PointInTimeRecoverySpec
 from serverless.aws.iam.dynamodb import DynamoDBFullAccess, DynamoDBReader, DynamoDBWriter
 from . import Resource
 from .kms import EncryptableResource
+from ...service import Identifier
 
 
 class Table(Resource, EncryptableResource):
@@ -18,6 +19,8 @@ class Table(Resource, EncryptableResource):
             SSESpecification(KMSMasterKeyId=self.encryption_key(), SSEEnabled=True, SSEType="KMS"),
         )
 
+        kwargs.setdefault("DeletionPolicy", "Retain")
+
         self.table = DynamoDBTable(
             title=TableName.replace("${sls:stage}", "").strip("-"), TableName=TableName, **kwargs
         )
@@ -42,6 +45,9 @@ class Table(Resource, EncryptableResource):
     def table_arn(self):
         return self.table.Ref().to_dict()
 
+    def variables(self):
+        return {"TABLE_" + Identifier(self.table.title).snake.upper(): self.table.TableName}
+
     def resources(self):
         return [self.table]
 
